#
# spec file for package linode-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cli_name    linode-cli
%bcond_without python2

Name:           linode-cli
Version:        5.25.0
Release:        3.4
Summary:        The Linode command-line interface
License:        BSD-3-Clause
URL:            https://github.com/linode/linode-cli
Source:         https://github.com/linode/linode-cli/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        openapi.yaml
# PATCH-FIX-OPENSUSE 0001-Remove-shebang-from-non-executable-files.patch
Patch0:         0001-Remove-shebang-from-non-executable-files.patch
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module terminaltables}
BuildRequires:  python-rpm-macros
%if %{with python2}
BuildRequires:  python-enum34
BuildRequires:  python2-future
%endif
Requires:       python-PyYAML
Requires:       python-requests
Requires:       python-terminaltables
%ifpython2
Requires:       python-enum34
Requires:       python2-future
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
The Linode Command Line interface

%package -n %{name}-bash-completion
Summary:        Bash completion for linode-cli
Group:          System/Shells
Supplements:    %{python_module linode-cli and bash-completion}
BuildArch:      noarch

%description -n %{name}-bash-completion

Bash completion files for %{name}

%prep
%autosetup -p1

%build
# harcode version to prevent calling out to git during build
echo "#!/bin/sh
echo %version" > version

# bake data files, output with different name based on the python version
%python_exec -m linodecli bake "%{SOURCE1}" --skip-config
cp data-* linodecli/

# run the actual build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/%{cli_name}

# move installed bash completions to proper location
install -d %{buildroot}%{_datarootdir}/bash-completion/completions
mv %{buildroot}%{_sysconfdir}/bash_completion.d/%{cli_name}.sh  %{buildroot}%{_datarootdir}/bash-completion/completions/%{cli_name}

%post
%python_install_alternative %{cli_name}

%postun
%python_uninstall_alternative %{cli_name}

%files %{python_files}
%python_alternative %{_bindir}/%{cli_name}
%{python_sitelib}/*

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{cli_name}

%changelog
* Tue Feb 27 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add dependency on setuptools
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Nov 10 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 5.25.0
  * refreshed openapi specs
  * Link to endpoint documentation in command help page
  * output: print default values being used
  * Add support for action aliasing
  * Add support for autocompletion
  * Accepted integer chunk_size instead of float
  * Refactor for Python 3
- refreshed the patch used to remove shebang line in __init__.py
* Tue May  3 2022 rombert@apache.org
- Update to version 5.19.0:
  * Make LKE test work through version rotations
* Tue Feb 15 2022 rombert@apache.org
- Update to version 5.17.1:
  * Make volume tests more resilient
  * Move Homebrew to new Community Distributions section
  * Mention Homebrew installation option in the README
  * run black to format files
  * run `isort . --profile=black` to sort imports
  * Run pycln to remove unused imports
  * Correctly fixed regex for new default nodebalancer dns
  * Update rdns name for new nodebalancers
  * Update linodecli/__init__.py
  * new: Warn python2 users of planned dropping of support
  * bug: Fix `linode-cli users view USERNAME`
  * bug: Follow redirects when downloading spec
  * ref: Stop recommending python2
  * bug: Remove commands with no actions from recognized commands
  * Fix tests more
  * bug: Make tests more durable
  * bug: Tests should accept new error output
  * bug: Fixed error output for CLI operations
* Sun Dec 26 2021 Robert Munteanu <rombert@apache.org>
- Initial packaging of version 5.13.1
